@@ -1,4 +1,6 @@
 # ruff: noqa: ARG001
+from __future__ import annotations
+
 import os
 import json
 from typing import Any, Dict, List, override
@@ -388,7 +390,6 @@ class At050AgentChatGuardrailsWorkflow(BaseWorkflow):
     @workflow.signal(name=SignalName.RECEIVE_EVENT)
     @override
     async def on_task_event_send(self, params: SendEventParams) -> None:
-        logger.info(f"Received task message instruction: {params}")
 
         if not params.event.content:
             return
