@@ -4,7 +4,7 @@ Debug functionality for AgentEx CLI
 Provides debug support for temporal workers and ACP servers during local development.
 """
 
-from .debug_config import DebugConfig, DebugMode
+from .debug_config import DebugMode, DebugConfig
 from .debug_handlers import start_acp_server_debug, start_temporal_worker_debug
 
 __all__ = [
