@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Any, Callable, AsyncGenerator, override
 from contextlib import asynccontextmanager
 
@@ -91,6 +93,7 @@ class TemporalACP(BaseACPServer):
                         agent=params.agent,
                         task=params.task,
                         event=params.event,
+                        request=params.request,
                     )
 
             except Exception as e:
