@@ -1,18 +1,19 @@
+# ruff: noqa: ARG001
 import asyncio
 from unittest.mock import AsyncMock, MagicMock, patch
 
 import httpx
 import pytest
 
-from agentex.lib.sdk.fastacp.impl.agentic_base_acp import AgenticBaseACP
-from agentex.lib.sdk.fastacp.impl.sync_acp import SyncACP
-from agentex.lib.sdk.fastacp.impl.temporal_acp import TemporalACP
 from agentex.lib.types.acp import (
-    CancelTaskParams,
-    CreateTaskParams,
     RPCMethod,
     SendEventParams,
+    CancelTaskParams,
+    CreateTaskParams,
 )
+from agentex.lib.sdk.fastacp.impl.sync_acp import SyncACP
+from agentex.lib.sdk.fastacp.impl.temporal_acp import TemporalACP
+from agentex.lib.sdk.fastacp.impl.agentic_base_acp import AgenticBaseACP
 
 
 class TestImplementationBehavior:
@@ -48,7 +49,7 @@ class TestImplementationBehavior:
                 mock_temporal_instance.temporal_client = MagicMock()
                 mock_create.return_value = mock_temporal_instance
 
-                temporal_acp = await TemporalACP.create()
+                temporal_acp = TemporalACP.create(temporal_address="localhost:7233")
 
                 assert temporal_acp == mock_temporal_instance
                 assert hasattr(temporal_acp, "temporal_client")
@@ -67,8 +68,8 @@ class TestRealWorldScenarios:
             messages_received.append(
                 {
                     "task_id": params.task.id,
-                    "message_content": params.message.content,
-                    "author": params.message.author,
+                    "message_content": params.message.content,  # type: ignore[attr-defined]
+                    "author": params.message.author,  # type: ignore[attr-defined]
                 }
             )
             return {"processed": True}
@@ -127,7 +128,7 @@ class TestRealWorldScenarios:
 
         @agentic_base_acp.on_task_cancel
         async def cancel_handler(params: CancelTaskParams):
-            task_events.append(("cancelled", params.task_id))
+            task_events.append(("cancelled", params.task_id))  # type: ignore[attr-defined]
 
         runner = test_server_runner(agentic_base_acp, free_port)
         await runner.start()
@@ -209,7 +210,7 @@ class TestErrorRecovery:
         @sync_acp.on_task_event_send
         async def unreliable_handler(params: SendEventParams):
             nonlocal failure_count, success_count
-            if "fail" in params.message.content:
+            if "fail" in params.message.content:  # type: ignore[attr-defined]
                 failure_count += 1
                 raise RuntimeError("Simulated handler failure")
             else:
@@ -326,7 +327,7 @@ class TestSpecialCases:
         @sync_acp.on_task_event_send
         async def tracking_handler(params: SendEventParams):
             nonlocal notifications_received, requests_received
-            if "notification" in params.message.content:
+            if "notification" in params.message.content:  # type: ignore[attr-defined]
                 notifications_received += 1
             else:
                 requests_received += 1
@@ -397,7 +398,7 @@ class TestSpecialCases:
         @sync_acp.on_task_event_send
         async def unicode_handler(params: SendEventParams):
             nonlocal received_message
-            received_message = params.message.content
+            received_message = params.message.content  # type: ignore[attr-defined]
             return {"unicode_handled": True}
 
         runner = test_server_runner(sync_acp, free_port)
@@ -458,9 +459,9 @@ class TestImplementationIsolation:
                 return {"agentic": True}
 
             # Create test parameters
-            message_params = SendEventParams(
+            message_params = SendEventParams(  # type: ignore[call-arg]
                 task={"id": "isolation-test-task", "agent_id": "test-agent", "status": "RUNNING"},
-                message={"type": "text", "author": "user", "content": "Isolation test"},
+                event={"type": "text", "author": "user", "content": "Isolation test"},  # type: ignore[misc]
             )
 
             # Execute sync handler
